/*
 * FILE:    IEmain.java
 * AUTHORS: Kristian Hasler
 * 
 * Copyright (c) 1999 University College London
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted, for non-commercial use only, provided
 * that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by the Computer Science
 *      Department at University College London
 * 4. Neither the name of the University nor of the Department may be used
 *    to endorse or promote products derived from this software without
 *    specific prior written permission.
 * Use of this software for commercial purposes is explicitly forbidden
 * unless prior written permission is obtained from the authors.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

import java.awt.*;
import java.applet.*;
import java.util.*;
import com.ms.security.*;

public class IEmain extends Applet implements Runnable
{
	private GUI gui;
	private ParseSDP sdp;

	protected void StartTool (String[] commandline) {
		if (commandline.equals(null)) return;
		PolicyEngine.assertPermission(PermissionID.EXEC);

		Runtime r = Runtime.getRuntime();
		Process rec;
		showStatus ("Starting "+commandline[0]);
		try {
			rec = r.exec (commandline);
		} catch (Exception e) {
			System.out.println(e);
			showStatus ("Error executing "+commandline[0]);
		}
	}

    public void init() {
		System.out.println("SDPP version 1.1");
		System.out.println("Operating System Name: "+System.getProperty("os.name"));

		try {
			PolicyEngine.assertPermission(PermissionID.EXEC);
		} catch (Throwable e) {
			showStatus("Failed! Unknown exception while enabling privilege.");
			e.printStackTrace(System.out);
			return;
		}
		System.out.println("Permission to execute programs granted by user.");

		gui=new GUI();
		setBackground(Color.white);
		add ("Center",gui);
		
		sdp=new	ParseSDP (getParameter("SDP"), getParameter("Separator"), gui);
	}

	public void run() {
	}

	public boolean handleEvent(Event event) {
		switch (event.id) {
		case Event.ACTION_EVENT:
			for (int i=0; i<sdp.tool; i++) {
				if (event.target==gui.button[i]) StartTool (sdp.BuildCL(i));
			}
			if (event.target==gui.startButton) {
				for (int i=0; i<sdp.tool; i++) {
					StartTool(sdp.BuildCL(i));
				}
			}
		break;
		}
	return true;
	}
}
