/*
 * FILE:    ParseSDP.java
 * AUTHORS: Kristian Hasler
 * 
 * Copyright (c) 1999 University College London
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted, for non-commercial use only, provided
 * that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by the Computer Science
 *      Department at University College London
 * 4. Neither the name of the University nor of the Department may be used
 *    to endorse or promote products derived from this software without
 *    specific prior written permission.
 * Use of this software for commercial purposes is explicitly forbidden
 * unless prior written permission is obtained from the authors.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHORS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
 
import java.awt.*;
import java.applet.*;
import java.util.*;

class ParseSDP {
	public String[] lines, address, port, ttl, format, media, key;
	public String desc;
	private int num_lines;
	public int tool=0;

	public ParseSDP(String SDPdata, String Separator, GUI gui) {
		if ((SDPdata.equals(null)) || (Separator.equals(null))) {
			System.out.println("Incorrect Parameters");
			return;
		}
		address=new String[4];
		ttl=new String[4];
		port=new String[4];
		format=new String[4];
		media=new String[4];
		key=new String[4];

		System.out.println ("SDP={"+SDPdata+"}");
		System.out.println ("SDP length="+SDPdata.length());
		System.out.println ("Separator={"+Separator+"}");
		System.out.println ("Parsing SDP...");
		SplitSDP (SDPdata, Separator);
		
		int i=0;
		// scan through lines
		while (i<num_lines) {
			if (lines[i].startsWith("s=")) {
				desc=lines[i].substring(2);
				gui.AddTitle (desc);
			}

			if (lines[i].startsWith("i=")) {
				gui.AddDesc (lines[i].substring(2));
			}

			if (lines[i].startsWith("m=")) {
				StringTokenizer t1=new StringTokenizer(lines[i], " ");
				media[tool]=(t1.nextToken()).substring(2);
				port[tool]=t1.nextToken();
				format[tool]=t1.nextToken();
				i++;

				if (lines[i].startsWith("c=")) {
					String addrport=lines[i].substring(9);
					StringTokenizer t2=new StringTokenizer(addrport, "/");
					address[tool]=t2.nextToken();
					ttl[tool]=t2.nextToken();
					i++;

					if (lines[i].startsWith("k=")) {
						key[tool]=lines[i].substring(8);
					} else {
						key[tool]="";
						i--;
					}
					gui.AddTool(tool, media[tool], address[tool], port[tool], ttl[tool], key[tool]);
					tool++;
				} else i--;
			}
			i++;
		}
	}

	protected void SplitSDP (String SDPdata, String Separator) {
		StringTokenizer t1=new StringTokenizer(SDPdata, Separator);
		num_lines=t1.countTokens();
		lines=new String[num_lines];
		for (int i=0; i<num_lines; i++) {
			lines[i]=t1.nextToken();
			System.out.println (lines[i]);
		}
	}

	public String[] BuildCL (int tool) {
		String keyflag, osname;
		String[] commandline;
		commandline=new String[8];
		osname=System.getProperty("os.name");

		if (media[tool].equals("audio")) {
			commandline[0]="rat";
			keyflag="-crypt";
		} else if (media[tool].equals("video")) {
			commandline[0]="vic";
			keyflag="-K";
		} else if (media[tool].equals("text")) {
			commandline[0]="nte";
			keyflag="-k";
		} else if (media[tool].equals("whiteboard")) {
			if (osname.equals("Windows 95")) commandline[0]="wbd";
			else commandline[0]="wb";
			keyflag="-K";
		} else {
			System.out.println("unknown format: "+media[tool]);
			return null;
		}

		commandline[1]="-C";
		if (osname.startsWith("Windows")) commandline[2]="\""+desc+"\"";
			else commandline[2]=desc;
		commandline[3]="-t";
		commandline[4]=ttl[tool];
		if (key.equals(""))	commandline[5]=address[tool]+"/"+port[tool];
		else {
			commandline[5]=keyflag;
			commandline[6]=key[tool];
			commandline[7]=address[tool]+"/"+port[tool];
		}
		return commandline;
	}
}